==> qtjambi-xml-6.5.1-sources.jar: io/qt/xml/QDomEntity.java <==
package io.qt.xml;

import io.qt.*;


/**
 * <p>Represents an XML entity</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qdomentity.html">QDomEntity</a></p>
 */
public class QDomEntity extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomentity.html#QDomEntity">QDomEntity::QDomEntity()</a></p>
     */
    public QDomEntity(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomEntity instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomentity.html#QDomEntity-1">QDomEntity::QDomEntity(QDomEntity)</a></p>
     */
    public QDomEntity(io.qt.xml.@NonNull QDomEntity x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomEntity instance, io.qt.xml.QDomEntity x);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomentity.html#notationName">QDomEntity::notationName()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String notationName(){
        return notationName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String notationName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomentity.html#operator-eq">QDomEntity::operator=(QDomEntity)</a></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xml.@NonNull QDomEntity arg__1){
        assign_native_cref_QDomEntity(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QDomEntity(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomentity.html#publicId">QDomEntity::publicId()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String publicId(){
        return publicId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String publicId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomentity.html#systemId">QDomEntity::systemId()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String systemId(){
        return systemId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String systemId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QDomEntity(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QDomEntity clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDomEntity clone_native(long __this_nativeId);
}

==> qtjambi-xml-6.5.2-sources.jar: io/qt/xml/QDomEntity.java <==
package io.qt.xml;

import io.qt.*;


/**
 * <p>Represents an XML entity</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qdomentity.html">QDomEntity</a></code></p>
 */
public class QDomEntity extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdomentity.html#QDomEntity">QDomEntity::<wbr>QDomEntity()</a></code></p>
     */
    public QDomEntity(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomEntity instance);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdomentity.html#QDomEntity-1">QDomEntity::<wbr>QDomEntity(QDomEntity)</a></code></p>
     */
    public QDomEntity(io.qt.xml.@NonNull QDomEntity x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomEntity instance, io.qt.xml.QDomEntity x);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdomentity.html#notationName">QDomEntity::<wbr>notationName()const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String notationName(){
        return notationName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String notationName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdomentity.html#operator-eq">QDomEntity::<wbr>operator=(QDomEntity)</a></code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xml.@NonNull QDomEntity arg__1){
        assign_native_cref_QDomEntity(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QDomEntity(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdomentity.html#publicId">QDomEntity::<wbr>publicId()const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String publicId(){
        return publicId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String publicId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qdomentity.html#systemId">QDomEntity::<wbr>systemId()const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String systemId(){
        return systemId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String systemId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QDomEntity(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QDomEntity clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDomEntity clone_native(long __this_nativeId);
}
